<template>
  <div class="system-add-user-container">
    <el-dialog :title="title" v-model="isShowDialog" width="50%">
      <el-form :model="form" size="default" ref="formRef" :rules="rules" label-width="120px">
        <el-row :gutter="35">
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="课程数量" prop="courseNum">
              <el-input v-model.trim.number="form.courseNum" placeholder="课程数量" type="number" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="课件数量" prop="coursewareNum">
              <el-input v-model.trim.number="form.coursewareNum" placeholder="课件数量" type="number" clearable></el-input>
            </el-form-item>
          </el-col>
          <el-col :xs="24" :sm="24" :md="24" :lg="24" :xl="24" class="mb20">
            <el-form-item label="试题数量" prop="questionsNum">
              <el-input v-model.trim.number="form.questionsNum" placeholder="试题数量" type="number" clearable></el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <template #footer>
        <span class="dialog-footer">
            <el-button @click="isShowDialog = !isShowDialog" size="default">取 消</el-button>
            <el-button type="primary" v-throttle @click="onSubmit" size="default">确 定</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>

<script lang="ts">
import { reactive, toRefs, onMounted, defineComponent, ref } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import axios from "axios";
import {workApplyApi} from "/@/api/specialWorkSystem/workApply";
import {educateTrainApi} from "/@/api/dataUpload/educateTrain";

// 定义接口来定义对象的类型
interface DataState {
  title: string
  isShowDialog: boolean
  form: {
    courseNum: number | null
    coursewareNum: number | null
    questionsNum: number | null
  }
  rules:{}
}

export default defineComponent({
  name: 'reportDialog',
  setup(props, context) {
    const formRef = ref()
    const state = reactive<DataState>({
      title: '',
      isShowDialog: false,
      form: {
        courseNum: null,
        coursewareNum: null,
        questionsNum: null
      },
      rules:{
        courseNum: [{ required: true, message: '请填写课程数量', trigger: 'blur' }],
        coursewareNum: [{ required: true, message: '请填写课件数量', trigger: 'blur' }],
        questionsNum: [{ required: true, message: '请填写试题数量', trigger: 'blur' }]
      }
    })

    // 页面加载时
    onMounted(() => {

    })
    // 打开弹窗
    const open = (type: string, data: object) => {
      state.isShowDialog = true;
      if (type === 'add') {
        state.title = '新增上报';
        state.form = {
          courseNum: null,
          coursewareNum: null,
          questionsNum: null
        }
      }
    };

    // 新增修改
    const onSubmit = async () => {
      formRef.value.validate(async (valid:Boolean) => {
        if(valid){
          const res = await educateTrainApi().addEducate([state.form])
          if(res.data.code == 200){
            ElMessage({
              type:'success',
              message:'数据上报成功'
            })
            state.isShowDialog = false
          }else{
            ElMessage({
              type:'warning',
              message:res.data.msg
            })
          }
          context.emit('refresh');
        }else{
          ElMessage({
            type:'warning',
            message:'请完善基本信息'
          })
        }
      })
    }

    return {
      formRef,
      open,
      onSubmit,
      ...toRefs(state)
    };
  }
});
</script>
